@@ -18,6 +18,7 @@ use crate::api_params::EditMessageMediaParams;
 use crate::api_params::EditMessageReplyMarkupParams;
 use crate::api_params::EditMessageTextParams;
 use crate::api_params::ExportChatInviteLinkParams;
+use crate::api_params::File;
 use crate::api_params::ForwardMessageParams;
 use crate::api_params::GetChatAdministratorsParams;
 use crate::api_params::GetChatMemberParams;
@@ -31,7 +32,7 @@ use crate::api_params::GetUserProfilePhotosParams;
 use crate::api_params::InputMedia;
 use crate::api_params::KickChatMemberParams;
 use crate::api_params::LeaveChatParams;
-use crate::api_params::MediaEnum;
+use crate::api_params::Media;
 use crate::api_params::PinChatMessageParams;
 use crate::api_params::PromoteChatMemberParams;
 use crate::api_params::RestrictChatMemberParams;
@@ -74,8 +75,7 @@ use crate::objects::BotCommand;
 use crate::objects::Chat;
 use crate::objects::ChatInviteLink;
 use crate::objects::ChatMember;
-use crate::objects::File;
-use crate::objects::FileEnum;
+use crate::objects::File as FileObject;
 use crate::objects::GameHighScore;
 use crate::objects::Message;
 use crate::objects::MessageId;
@@ -172,7 +172,7 @@ pub trait TelegramApi {
         let method_name = "sendPhoto";
         let mut files: Vec<(&str, PathBuf)> = vec![];
 
-        if let FileEnum::InputFileVariant(input_file) = params.photo() {
+        if let File::InputFile(input_file) = params.photo() {
             files.push(("photo", input_file.path()));
         }
 
@@ -183,11 +183,11 @@ pub trait TelegramApi {
         let method_name = "sendAudio";
         let mut files: Vec<(&str, PathBuf)> = vec![];
 
-        if let FileEnum::InputFileVariant(input_file) = params.audio() {
+        if let File::InputFile(input_file) = params.audio() {
             files.push(("audio", input_file.path()));
         }
 
-        if let Some(FileEnum::InputFileVariant(input_file)) = params.thumb() {
+        if let Some(File::InputFile(input_file)) = params.thumb() {
             files.push(("thumb", input_file.path()));
         }
 
@@ -200,92 +200,92 @@ pub trait TelegramApi {
     ) -> Result<MethodResponse<Vec<Message>>, Self::Error> {
         let method_name = "sendMediaGroup";
         let mut files: Vec<(String, PathBuf)> = vec![];
-        let mut new_medias: Vec<MediaEnum> = vec![];
+        let mut new_medias: Vec<Media> = vec![];
         let mut file_idx = 0;
 
         for media in params.media() {
             match media {
-                MediaEnum::InputMediaAudioVariant(audio) => {
+                Media::Audio(audio) => {
                     let mut new_audio = audio.clone();
 
-                    if let FileEnum::InputFileVariant(input_file) = audio.media() {
+                    if let File::InputFile(input_file) = audio.media() {
                         let name = format!("file{}", file_idx);
                         let attach_name = format!("attach://{}", name);
                         file_idx += 1;
 
-                        new_audio.set_media(FileEnum::StringVariant(attach_name));
+                        new_audio.set_media(File::String(attach_name));
 
                         files.push((name, input_file.path()));
                     };
 
-                    if let Some(FileEnum::InputFileVariant(input_file)) = audio.thumb() {
+                    if let Some(File::InputFile(input_file)) = audio.thumb() {
                         let name = format!("file{}", file_idx);
                         let attach_name = format!("attach://{}", name);
                         file_idx += 1;
 
-                        new_audio.set_thumb(Some(FileEnum::StringVariant(attach_name)));
+                        new_audio.set_thumb(Some(File::String(attach_name)));
 
                         files.push((name, input_file.path()));
                     };
 
-                    new_medias.push(MediaEnum::InputMediaAudioVariant(new_audio));
+                    new_medias.push(Media::Audio(new_audio));
                 }
 
-                MediaEnum::InputMediaDocumentVariant(document) => {
+                Media::Document(document) => {
                     let mut new_document = document.clone();
 
-                    if let FileEnum::InputFileVariant(input_file) = document.media() {
+                    if let File::InputFile(input_file) = document.media() {
                         let name = format!("file{}", file_idx);
                         let attach_name = format!("attach://{}", name);
                         file_idx += 1;
 
-                        new_document.set_media(FileEnum::StringVariant(attach_name));
+                        new_document.set_media(File::String(attach_name));
 
                         files.push((name, input_file.path()));
                     };
 
-                    new_medias.push(MediaEnum::InputMediaDocumentVariant(new_document));
+                    new_medias.push(Media::Document(new_document));
                 }
-                MediaEnum::InputMediaPhotoVariant(photo) => {
+                Media::Photo(photo) => {
                     let mut new_photo = photo.clone();
 
-                    if let FileEnum::InputFileVariant(input_file) = photo.media() {
+                    if let File::InputFile(input_file) = photo.media() {
                         let name = format!("file{}", file_idx);
                         let attach_name = format!("attach://{}", name);
                         file_idx += 1;
 
-                        new_photo.set_media(FileEnum::StringVariant(attach_name));
+                        new_photo.set_media(File::String(attach_name));
 
                         files.push((name, input_file.path()));
                     };
 
-                    new_medias.push(MediaEnum::InputMediaPhotoVariant(new_photo));
+                    new_medias.push(Media::Photo(new_photo));
                 }
 
-                MediaEnum::InputMediaVideoVariant(video) => {
+                Media::Video(video) => {
                     let mut new_video = video.clone();
 
-                    if let FileEnum::InputFileVariant(input_file) = video.media() {
+                    if let File::InputFile(input_file) = video.media() {
                         let name = format!("file{}", file_idx);
                         let attach_name = format!("attach://{}", name);
                         file_idx += 1;
 
-                        new_video.set_media(FileEnum::StringVariant(attach_name));
+                        new_video.set_media(File::String(attach_name));
 
                         files.push((name, input_file.path()));
                     };
 
-                    if let Some(FileEnum::InputFileVariant(input_file)) = video.thumb() {
+                    if let Some(File::InputFile(input_file)) = video.thumb() {
                         let name = format!("file{}", file_idx);
                         let attach_name = format!("attach://{}", name);
                         file_idx += 1;
 
-                        new_video.set_thumb(Some(FileEnum::StringVariant(attach_name)));
+                        new_video.set_thumb(Some(File::String(attach_name)));
 
                         files.push((name, input_file.path()));
                     };
 
-                    new_medias.push(MediaEnum::InputMediaVideoVariant(new_video));
+                    new_medias.push(Media::Video(new_video));
                 }
             };
         }
@@ -308,11 +308,11 @@ pub trait TelegramApi {
         let method_name = "sendDocument";
         let mut files: Vec<(&str, PathBuf)> = vec![];
 
-        if let FileEnum::InputFileVariant(input_file) = params.document() {
+        if let File::InputFile(input_file) = params.document() {
             files.push(("document", input_file.path()));
         }
 
-        if let Some(FileEnum::InputFileVariant(input_file)) = params.thumb() {
+        if let Some(File::InputFile(input_file)) = params.thumb() {
             files.push(("thumb", input_file.path()));
         }
 
@@ -323,11 +323,11 @@ pub trait TelegramApi {
         let method_name = "sendVideo";
         let mut files: Vec<(&str, PathBuf)> = vec![];
 
-        if let FileEnum::InputFileVariant(input_file) = params.video() {
+        if let File::InputFile(input_file) = params.video() {
             files.push(("video", input_file.path()));
         }
 
-        if let Some(FileEnum::InputFileVariant(input_file)) = params.thumb() {
+        if let Some(File::InputFile(input_file)) = params.thumb() {
             files.push(("thumb", input_file.path()));
         }
 
@@ -341,11 +341,11 @@ pub trait TelegramApi {
         let method_name = "sendAnimation";
         let mut files: Vec<(&str, PathBuf)> = vec![];
 
-        if let FileEnum::InputFileVariant(input_file) = params.animation() {
+        if let File::InputFile(input_file) = params.animation() {
             files.push(("animation", input_file.path()));
         }
 
-        if let Some(FileEnum::InputFileVariant(input_file)) = params.thumb() {
+        if let Some(File::InputFile(input_file)) = params.thumb() {
             files.push(("thumb", input_file.path()));
         }
 
@@ -356,7 +356,7 @@ pub trait TelegramApi {
         let method_name = "sendVoice";
         let mut files: Vec<(&str, PathBuf)> = vec![];
 
-        if let FileEnum::InputFileVariant(input_file) = params.voice() {
+        if let File::InputFile(input_file) = params.voice() {
             files.push(("voice", input_file.path()));
         }
 
@@ -370,11 +370,11 @@ pub trait TelegramApi {
         let method_name = "sendVideoNote";
         let mut files: Vec<(&str, PathBuf)> = vec![];
 
-        if let FileEnum::InputFileVariant(input_file) = params.video_note() {
+        if let File::InputFile(input_file) = params.video_note() {
             files.push(("video_note", input_file.path()));
         }
 
-        if let Some(FileEnum::InputFileVariant(input_file)) = params.thumb() {
+        if let Some(File::InputFile(input_file)) = params.thumb() {
             files.push(("thumb", input_file.path()));
         }
 
@@ -435,7 +435,7 @@ pub trait TelegramApi {
         self.request("getUserProfilePhotos", Some(params))
     }
 
-    fn get_file(&self, params: &GetFileParams) -> Result<MethodResponse<File>, Self::Error> {
+    fn get_file(&self, params: &GetFileParams) -> Result<MethodResponse<FileObject>, Self::Error> {
         self.request("getFile", Some(params))
     }
 
@@ -571,7 +571,7 @@ pub trait TelegramApi {
     fn get_chat_members_count(
         &self,
         params: &GetChatMembersCountParams,
-    ) -> Result<MethodResponse<usize>, Self::Error> {
+    ) -> Result<MethodResponse<u32>, Self::Error> {
         self.request("getChatMembersCount", Some(params))
     }
 
@@ -643,111 +643,111 @@ pub trait TelegramApi {
         let mut files: Vec<(String, PathBuf)> = vec![];
 
         let new_media = match params.media() {
-            InputMedia::InputMediaAnimationVariant(animation) => {
+            InputMedia::Animation(animation) => {
                 let mut new_animation = animation.clone();
 
-                if let FileEnum::InputFileVariant(input_file) = animation.media() {
+                if let File::InputFile(input_file) = animation.media() {
                     let name = "animation".to_string();
                     let attach_name = format!("attach://{}", name);
 
-                    new_animation.set_media(FileEnum::StringVariant(attach_name));
+                    new_animation.set_media(File::String(attach_name));
 
                     files.push((name, input_file.path()));
                 };
 
-                if let Some(FileEnum::InputFileVariant(input_file)) = animation.thumb() {
+                if let Some(File::InputFile(input_file)) = animation.thumb() {
                     let name = "animation_thumb".to_string();
                     let attach_name = format!("attach://{}", name);
 
-                    new_animation.set_thumb(Some(FileEnum::StringVariant(attach_name)));
+                    new_animation.set_thumb(Some(File::String(attach_name)));
 
                     files.push((name, input_file.path()));
                 };
 
-                InputMedia::InputMediaAnimationVariant(new_animation)
+                InputMedia::Animation(new_animation)
             }
-            InputMedia::InputMediaDocumentVariant(document) => {
+            InputMedia::Document(document) => {
                 let mut new_document = document.clone();
 
-                if let FileEnum::InputFileVariant(input_file) = document.media() {
+                if let File::InputFile(input_file) = document.media() {
                     let name = "document".to_string();
                     let attach_name = format!("attach://{}", name);
 
-                    new_document.set_media(FileEnum::StringVariant(attach_name));
+                    new_document.set_media(File::String(attach_name));
 
                     files.push((name, input_file.path()));
                 };
 
-                if let Some(FileEnum::InputFileVariant(input_file)) = document.thumb() {
+                if let Some(File::InputFile(input_file)) = document.thumb() {
                     let name = "document_thumb".to_string();
                     let attach_name = format!("attach://{}", name);
 
-                    new_document.set_thumb(Some(FileEnum::StringVariant(attach_name)));
+                    new_document.set_thumb(Some(File::String(attach_name)));
 
                     files.push((name, input_file.path()));
                 };
 
-                InputMedia::InputMediaDocumentVariant(new_document)
+                InputMedia::Document(new_document)
             }
-            InputMedia::InputMediaAudioVariant(audio) => {
+            InputMedia::Audio(audio) => {
                 let mut new_audio = audio.clone();
 
-                if let FileEnum::InputFileVariant(input_file) = audio.media() {
+                if let File::InputFile(input_file) = audio.media() {
                     let name = "audio".to_string();
                     let attach_name = format!("attach://{}", name);
 
-                    new_audio.set_media(FileEnum::StringVariant(attach_name));
+                    new_audio.set_media(File::String(attach_name));
 
                     files.push((name, input_file.path()));
                 };
 
-                if let Some(FileEnum::InputFileVariant(input_file)) = audio.thumb() {
+                if let Some(File::InputFile(input_file)) = audio.thumb() {
                     let name = "audio_thumb".to_string();
                     let attach_name = format!("attach://{}", name);
 
-                    new_audio.set_thumb(Some(FileEnum::StringVariant(attach_name)));
+                    new_audio.set_thumb(Some(File::String(attach_name)));
 
                     files.push((name, input_file.path()));
                 };
 
-                InputMedia::InputMediaAudioVariant(new_audio)
+                InputMedia::Audio(new_audio)
             }
-            InputMedia::InputMediaPhotoVariant(photo) => {
+            InputMedia::Photo(photo) => {
                 let mut new_photo = photo.clone();
 
-                if let FileEnum::InputFileVariant(input_file) = photo.media() {
+                if let File::InputFile(input_file) = photo.media() {
                     let name = "photo".to_string();
                     let attach_name = format!("attach://{}", name);
 
-                    new_photo.set_media(FileEnum::StringVariant(attach_name));
+                    new_photo.set_media(File::String(attach_name));
 
                     files.push((name, input_file.path()));
                 };
 
-                InputMedia::InputMediaPhotoVariant(new_photo)
+                InputMedia::Photo(new_photo)
             }
-            InputMedia::InputMediaVideoVariant(video) => {
+            InputMedia::Video(video) => {
                 let mut new_video = video.clone();
 
-                if let FileEnum::InputFileVariant(input_file) = video.media() {
+                if let File::InputFile(input_file) = video.media() {
                     let name = "video".to_string();
                     let attach_name = format!("attach://{}", name);
 
-                    new_video.set_media(FileEnum::StringVariant(attach_name));
+                    new_video.set_media(File::String(attach_name));
 
                     files.push((name, input_file.path()));
                 };
 
-                if let Some(FileEnum::InputFileVariant(input_file)) = video.thumb() {
+                if let Some(File::InputFile(input_file)) = video.thumb() {
                     let name = "video_thumb".to_string();
                     let attach_name = format!("attach://{}", name);
 
-                    new_video.set_thumb(Some(FileEnum::StringVariant(attach_name)));
+                    new_video.set_thumb(Some(File::String(attach_name)));
 
                     files.push((name, input_file.path()));
                 };
 
-                InputMedia::InputMediaVideoVariant(new_video)
+                InputMedia::Video(new_video)
             }
         };
 
@@ -787,7 +787,7 @@ pub trait TelegramApi {
         let method_name = "sendSticker";
         let mut files: Vec<(&str, PathBuf)> = vec![];
 
-        if let FileEnum::InputFileVariant(input_file) = params.sticker() {
+        if let File::InputFile(input_file) = params.sticker() {
             files.push(("sticker", input_file.path()));
         }
 
@@ -821,7 +821,7 @@ pub trait TelegramApi {
         let method_name = "createNewStickerSet";
         let mut files: Vec<(&str, PathBuf)> = vec![];
 
-        if let Some(FileEnum::InputFileVariant(input_file)) = params.png_sticker() {
+        if let Some(File::InputFile(input_file)) = params.png_sticker() {
             files.push(("png_sticker", input_file.path()));
         }
 
@@ -839,7 +839,7 @@ pub trait TelegramApi {
         let method_name = "addStickerToSet";
         let mut files: Vec<(&str, PathBuf)> = vec![];
 
-        if let Some(FileEnum::InputFileVariant(input_file)) = params.png_sticker() {
+        if let Some(File::InputFile(input_file)) = params.png_sticker() {
             files.push(("png_sticker", input_file.path()));
         }
 
@@ -871,7 +871,7 @@ pub trait TelegramApi {
         let method_name = "setStickerSetThumb";
         let mut files: Vec<(&str, PathBuf)> = vec![];
 
-        if let Some(FileEnum::InputFileVariant(input_file)) = params.thumb() {
+        if let Some(File::InputFile(input_file)) = params.thumb() {
             files.push(("thumb", input_file.path()));
         }
 
